window.Gleam.initSearch([{"doc":"loan","title":"loan","content":"# gleam loan\n\n[![Package Version](https://img.shields.io/hexpm/v/loan)](https://hex.pm/packages/loan)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/loan/)\n\n```sh\ngleam add loan@1\n```\n```gleam\nimport loan\n\npub fn main() {\n  let loan =\n    loan.Loan(\n      initial_principal: 3_000_000,\n      remaining_principal: 3_000_000,\n      interest: 0.03,\n      term: 360,\n      period: 12,\n    )\n  let amortization_schedule = loan.amortization_schedule(loan)\n  io.debug(amortization_schedule)\n\n  let amortized_payment = loan.amortized_payment(loan)\n  io.debug(amortized_payment)\n\n  let interest_payment = loan.interest_payment(loan)\n  io.debug(interest_payment)\n\n  let total_paid = loan.total_paid(loan)\n  io.debug(total_paid)\n\n  let total_interest = loan.total_interest_paid(loan)\n  io.debug(total_interest)\n\n  io.debug(loan.initial_principal)\n  io.debug(loan.remaining_principal)\n  io.debug(loan.interest)\n  io.debug(loan.term)\n  io.debug(loan.period)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/loan&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"loan","title":"Loan","content":"pub type Loan {\n  Loan(\n    initial_principal: Int,\n    remaining_principal: Int,\n    interest: Float,\n    term: Int,\n    period: Int,\n  )\n}\n\nLoan(\n  initial_principal: Int,\n  remaining_principal: Int,\n  interest: Float,\n  term: Int,\n  period: Int,\n)\n\ninitial_principal\n&lt;p&gt;amount of the loan in cents at the start of the loan&lt;/p&gt;\n\nremaining_principal\n&lt;p&gt;amount of the loan in cents that currently remain&lt;/p&gt;\n\ninterest\n&lt;p&gt;annual interest rate&lt;/p&gt;\n\nterm\n&lt;p&gt;number of individual payments to be made over the life of the loan&lt;/p&gt;\n\nperiod\n&lt;p&gt;number of payments in a period for which to apply interest\ne.g. 12 for monthly\ne.g. 4 for quarterly&lt;/p&gt;\n\nSynonyms:\nloan.Loan\nloan Loan","url":"loan.html#Loan"},{"doc":"loan","title":"ScheduleItem","content":"pub type ScheduleItem {\n  ScheduleItem(\n    payment_number: Int,\n    payment_amount: Int,\n    interest_payment: Int,\n    principal_payment: Int,\n    remaining_principal: Int,\n  )\n}\n\nScheduleItem(\n  payment_number: Int,\n  payment_amount: Int,\n  interest_payment: Int,\n  principal_payment: Int,\n  remaining_principal: Int,\n)\n\npayment_number\n&lt;p&gt;the payment number&lt;/p&gt;\n\npayment_amount\n&lt;p&gt;the amount of the payment in cents&lt;/p&gt;\n\ninterest_payment\n&lt;p&gt;the amount of the payment that goes to interest in cents&lt;/p&gt;\n\nprincipal_payment\n&lt;p&gt;the amount of the payment that goes to principal in cents&lt;/p&gt;\n\nremaining_principal\n&lt;p&gt;the remaining principal balance of the loan in cents&lt;/p&gt;\n\nSynonyms:\nloan.ScheduleItem\nloan ScheduleItem","url":"loan.html#ScheduleItem"},{"doc":"loan","title":"amortization_schedule","content":"pub fn amortization_schedule(\n  loan: Loan,\n) -&gt; Result(List(ScheduleItem), Nil)\n Calculate the amortization schedule for a loan\nSynonyms:\nloan.amortization_schedule\nloan amortization_schedule","url":"loan.html#amortization_schedule"},{"doc":"loan","title":"amortized_payment","content":"pub fn amortized_payment(loan: Loan) -&gt; Result(Int, Nil)\n Calculate the individual amortized payment for a loan\n\n Returns the amortized payment in cents\nSynonyms:\nloan.amortized_payment\nloan amortized_payment","url":"loan.html#amortized_payment"},{"doc":"loan","title":"interest_payment","content":"pub fn interest_payment(loan: Loan) -&gt; Int\n Calculate the interest payment for a loan\n\n Returns the interest payment in cents\nSynonyms:\nloan.interest_payment\nloan interest_payment","url":"loan.html#interest_payment"},{"doc":"loan","title":"total_interest_paid","content":"pub fn total_interest_paid(loan: Loan) -&gt; Int\n\nSynonyms:\nloan.total_interest_paid\nloan total_interest_paid","url":"loan.html#total_interest_paid"},{"doc":"loan","title":"total_paid","content":"pub fn total_paid(loan: Loan) -&gt; Int\n\nSynonyms:\nloan.total_paid\nloan total_paid","url":"loan.html#total_paid"},{"doc":"loan","title":"loan","content":"","url":"loan.html"}]);